==> lighttpd-1.4.53-1.tar.xz: etc/postinstall/lighttpd.sh <==
if [ ! -f /etc/lighttpd/conf.d/access_log.conf ]
then
    /usr/bin/mkdir -p /etc/lighttpd/conf.d
    /usr/bin/cp /etc/defaults/etc/lighttpd/conf.d/access_log.conf /etc/lighttpd/conf.d/access_log.conf
fi

if [ ! -f /etc/lighttpd/conf.d/auth.conf ]
then
    /usr/bin/mkdir -p /etc/lighttpd/conf.d
    /usr/bin/cp /etc/defaults/etc/lighttpd/conf.d/auth.conf /etc/lighttpd/conf.d/auth.conf
fi

if [ ! -f /etc/lighttpd/conf.d/cgi.conf ]
then
    /usr/bin/mkdir -p /etc/lighttpd/conf.d
    /usr/bin/cp /etc/defaults/etc/lighttpd/conf.d/cgi.conf /etc/lighttpd/conf.d/cgi.conf
fi

if [ ! -f /etc/lighttpd/conf.d/cml.conf ]
then
    /usr/bin/mkdir -p /etc/lighttpd/conf.d
    /usr/bin/cp /etc/defaults/etc/lighttpd/conf.d/cml.conf /etc/lighttpd/conf.d/cml.conf
fi

if [ ! -f /etc/lighttpd/conf.d/compress.conf ]
then
    /usr/bin/mkdir -p /etc/lighttpd/conf.d
    /usr/bin/cp /etc/defaults/etc/lighttpd/conf.d/compress.conf /etc/lighttpd/conf.d/compress.conf
fi

if [ ! -f /etc/lighttpd/conf.d/debug.conf ]
then
    /usr/bin/mkdir -p /etc/lighttpd/conf.d
    /usr/bin/cp /etc/defaults/etc/lighttpd/conf.d/debug.conf /etc/lighttpd/conf.d/debug.conf
fi

if [ ! -f /etc/lighttpd/conf.d/dirlisting.conf ]
then
    /usr/bin/mkdir -p /etc/lighttpd/conf.d
    /usr/bin/cp /etc/defaults/etc/lighttpd/conf.d/dirlisting.conf /etc/lighttpd/conf.d/dirlisting.conf
fi

if [ ! -f /etc/lighttpd/conf.d/evhost.conf ]
then
    /usr/bin/mkdir -p /etc/lighttpd/conf.d
    /usr/bin/cp /etc/defaults/etc/lighttpd/conf.d/evhost.conf /etc/lighttpd/conf.d/evhost.conf
fi

if [ ! -f /etc/lighttpd/conf.d/expire.conf ]
then
    /usr/bin/mkdir -p /etc/lighttpd/conf.d
    /usr/bin/cp /etc/defaults/etc/lighttpd/conf.d/expire.conf /etc/lighttpd/conf.d/expire.conf
fi

if [ ! -f /etc/lighttpd/conf.d/fastcgi.conf ]
then
    /usr/bin/mkdir -p /etc/lighttpd/conf.d
    /usr/bin/cp /etc/defaults/etc/lighttpd/conf.d/fastcgi.conf /etc/lighttpd/conf.d/fastcgi.conf
fi

if [ ! -f /etc/lighttpd/conf.d/geoip.conf ]
then
    /usr/bin/mkdir -p /etc/lighttpd/conf.d
    /usr/bin/cp /etc/defaults/etc/lighttpd/conf.d/geoip.conf /etc/lighttpd/conf.d/geoip.conf
fi

if [ ! -f /etc/lighttpd/conf.d/magnet.conf ]
then
    /usr/bin/mkdir -p /etc/lighttpd/conf.d
    /usr/bin/cp /etc/defaults/etc/lighttpd/conf.d/magnet.conf /etc/lighttpd/conf.d/magnet.conf
fi

if [ ! -f /etc/lighttpd/conf.d/mime.conf ]
then
    /usr/bin/mkdir -p /etc/lighttpd/conf.d
    /usr/bin/cp /etc/defaults/etc/lighttpd/conf.d/mime.conf /etc/lighttpd/conf.d/mime.conf
fi

if [ ! -f /etc/lighttpd/conf.d/mysql_vhost.conf ]
then
    /usr/bin/mkdir -p /etc/lighttpd/conf.d
    /usr/bin/cp /etc/defaults/etc/lighttpd/conf.d/mysql_vhost.conf /etc/lighttpd/conf.d/mysql_vhost.conf
fi

if [ ! -f /etc/lighttpd/conf.d/proxy.conf ]
then
    /usr/bin/mkdir -p /etc/lighttpd/conf.d
    /usr/bin/cp /etc/defaults/etc/lighttpd/conf.d/proxy.conf /etc/lighttpd/conf.d/proxy.conf
fi

if [ ! -f /etc/lighttpd/conf.d/rrdtool.conf ]
then
    /usr/bin/mkdir -p /etc/lighttpd/conf.d
    /usr/bin/cp /etc/defaults/etc/lighttpd/conf.d/rrdtool.conf /etc/lighttpd/conf.d/rrdtool.conf
fi

if [ ! -f /etc/lighttpd/conf.d/scgi.conf ]
then
    /usr/bin/mkdir -p /etc/lighttpd/conf.d
    /usr/bin/cp /etc/defaults/etc/lighttpd/conf.d/scgi.conf /etc/lighttpd/conf.d/scgi.conf
fi

if [ ! -f /etc/lighttpd/conf.d/secdownload.conf ]
then
    /usr/bin/mkdir -p /etc/lighttpd/conf.d
    /usr/bin/cp /etc/defaults/etc/lighttpd/conf.d/secdownload.conf /etc/lighttpd/conf.d/secdownload.conf
fi

if [ ! -f /etc/lighttpd/conf.d/simple_vhost.conf ]
then
    /usr/bin/mkdir -p /etc/lighttpd/conf.d
    /usr/bin/cp /etc/defaults/etc/lighttpd/conf.d/simple_vhost.conf /etc/lighttpd/conf.d/simple_vhost.conf
fi

if [ ! -f /etc/lighttpd/conf.d/ssi.conf ]
then
    /usr/bin/mkdir -p /etc/lighttpd/conf.d
    /usr/bin/cp /etc/defaults/etc/lighttpd/conf.d/ssi.conf /etc/lighttpd/conf.d/ssi.conf
fi

if [ ! -f /etc/lighttpd/conf.d/status.conf ]
then
    /usr/bin/mkdir -p /etc/lighttpd/conf.d
    /usr/bin/cp /etc/defaults/etc/lighttpd/conf.d/status.conf /etc/lighttpd/conf.d/status.conf
fi

if [ ! -f /etc/lighttpd/conf.d/trigger_b4_dl.conf ]
then
    /usr/bin/mkdir -p /etc/lighttpd/conf.d
    /usr/bin/cp /etc/defaults/etc/lighttpd/conf.d/trigger_b4_dl.conf /etc/lighttpd/conf.d/trigger_b4_dl.conf
fi

if [ ! -f /etc/lighttpd/conf.d/userdir.conf ]
then
    /usr/bin/mkdir -p /etc/lighttpd/conf.d
    /usr/bin/cp /etc/defaults/etc/lighttpd/conf.d/userdir.conf /etc/lighttpd/conf.d/userdir.conf
fi

if [ ! -f /etc/lighttpd/conf.d/webdav.conf ]
then
    /usr/bin/mkdir -p /etc/lighttpd/conf.d
    /usr/bin/cp /etc/defaults/etc/lighttpd/conf.d/webdav.conf /etc/lighttpd/conf.d/webdav.conf
fi

if [ ! -f /etc/lighttpd/lighttpd.conf ]
then
    /usr/bin/mkdir -p /etc/lighttpd
    /usr/bin/cp /etc/defaults/etc/lighttpd/lighttpd.conf /etc/lighttpd/lighttpd.conf
fi

if [ ! -f /etc/lighttpd/modules.conf ]
then
    /usr/bin/mkdir -p /etc/lighttpd
    /usr/bin/cp /etc/defaults/etc/lighttpd/modules.conf /etc/lighttpd/modules.conf
fi

if [ ! -f /etc/lighttpd/vhosts.d/vhosts.template ]
then
    /usr/bin/mkdir -p /etc/lighttpd/vhosts.d
    /usr/bin/cp /etc/defaults/etc/lighttpd/vhosts.d/vhosts.template /etc/lighttpd/vhosts.d/vhosts.template
fi

==> lighttpd-1.4.66-1.tar.xz: etc/postinstall/lighttpd.sh <==
if [ ! -e /etc/lighttpd/conf.d/access_log.conf ]
then
    /usr/bin/mkdir -p /etc/lighttpd/conf.d
    /usr/bin/cp /etc/defaults/etc/lighttpd/conf.d/access_log.conf /etc/lighttpd/conf.d/access_log.conf
fi

if [ ! -e /etc/lighttpd/conf.d/auth.conf ]
then
    /usr/bin/mkdir -p /etc/lighttpd/conf.d
    /usr/bin/cp /etc/defaults/etc/lighttpd/conf.d/auth.conf /etc/lighttpd/conf.d/auth.conf
fi

if [ ! -e /etc/lighttpd/conf.d/cgi.conf ]
then
    /usr/bin/mkdir -p /etc/lighttpd/conf.d
    /usr/bin/cp /etc/defaults/etc/lighttpd/conf.d/cgi.conf /etc/lighttpd/conf.d/cgi.conf
fi

if [ ! -e /etc/lighttpd/conf.d/debug.conf ]
then
    /usr/bin/mkdir -p /etc/lighttpd/conf.d
    /usr/bin/cp /etc/defaults/etc/lighttpd/conf.d/debug.conf /etc/lighttpd/conf.d/debug.conf
fi

if [ ! -e /etc/lighttpd/conf.d/deflate.conf ]
then
    /usr/bin/mkdir -p /etc/lighttpd/conf.d
    /usr/bin/cp /etc/defaults/etc/lighttpd/conf.d/deflate.conf /etc/lighttpd/conf.d/deflate.conf
fi

if [ ! -e /etc/lighttpd/conf.d/dirlisting.conf ]
then
    /usr/bin/mkdir -p /etc/lighttpd/conf.d
    /usr/bin/cp /etc/defaults/etc/lighttpd/conf.d/dirlisting.conf /etc/lighttpd/conf.d/dirlisting.conf
fi

if [ ! -e /etc/lighttpd/conf.d/evhost.conf ]
then
    /usr/bin/mkdir -p /etc/lighttpd/conf.d
    /usr/bin/cp /etc/defaults/etc/lighttpd/conf.d/evhost.conf /etc/lighttpd/conf.d/evhost.conf
fi

if [ ! -e /etc/lighttpd/conf.d/expire.conf ]
then
    /usr/bin/mkdir -p /etc/lighttpd/conf.d
    /usr/bin/cp /etc/defaults/etc/lighttpd/conf.d/expire.conf /etc/lighttpd/conf.d/expire.conf
fi

if [ ! -e /etc/lighttpd/conf.d/fastcgi.conf ]
then
    /usr/bin/mkdir -p /etc/lighttpd/conf.d
    /usr/bin/cp /etc/defaults/etc/lighttpd/conf.d/fastcgi.conf /etc/lighttpd/conf.d/fastcgi.conf
fi

if [ ! -e /etc/lighttpd/conf.d/magnet.conf ]
then
    /usr/bin/mkdir -p /etc/lighttpd/conf.d
    /usr/bin/cp /etc/defaults/etc/lighttpd/conf.d/magnet.conf /etc/lighttpd/conf.d/magnet.conf
fi

if [ ! -e /etc/lighttpd/conf.d/mime.conf ]
then
    /usr/bin/mkdir -p /etc/lighttpd/conf.d
    /usr/bin/cp /etc/defaults/etc/lighttpd/conf.d/mime.conf /etc/lighttpd/conf.d/mime.conf
fi

if [ ! -e /etc/lighttpd/conf.d/proxy.conf ]
then
    /usr/bin/mkdir -p /etc/lighttpd/conf.d
    /usr/bin/cp /etc/defaults/etc/lighttpd/conf.d/proxy.conf /etc/lighttpd/conf.d/proxy.conf
fi

if [ ! -e /etc/lighttpd/conf.d/rrdtool.conf ]
then
    /usr/bin/mkdir -p /etc/lighttpd/conf.d
    /usr/bin/cp /etc/defaults/etc/lighttpd/conf.d/rrdtool.conf /etc/lighttpd/conf.d/rrdtool.conf
fi

if [ ! -e /etc/lighttpd/conf.d/scgi.conf ]
then
    /usr/bin/mkdir -p /etc/lighttpd/conf.d
    /usr/bin/cp /etc/defaults/etc/lighttpd/conf.d/scgi.conf /etc/lighttpd/conf.d/scgi.conf
fi

if [ ! -e /etc/lighttpd/conf.d/secdownload.conf ]
then
    /usr/bin/mkdir -p /etc/lighttpd/conf.d
    /usr/bin/cp /etc/defaults/etc/lighttpd/conf.d/secdownload.conf /etc/lighttpd/conf.d/secdownload.conf
fi

if [ ! -e /etc/lighttpd/conf.d/simple_vhost.conf ]
then
    /usr/bin/mkdir -p /etc/lighttpd/conf.d
    /usr/bin/cp /etc/defaults/etc/lighttpd/conf.d/simple_vhost.conf /etc/lighttpd/conf.d/simple_vhost.conf
fi

if [ ! -e /etc/lighttpd/conf.d/ssi.conf ]
then
    /usr/bin/mkdir -p /etc/lighttpd/conf.d
    /usr/bin/cp /etc/defaults/etc/lighttpd/conf.d/ssi.conf /etc/lighttpd/conf.d/ssi.conf
fi

if [ ! -e /etc/lighttpd/conf.d/status.conf ]
then
    /usr/bin/mkdir -p /etc/lighttpd/conf.d
    /usr/bin/cp /etc/defaults/etc/lighttpd/conf.d/status.conf /etc/lighttpd/conf.d/status.conf
fi

if [ ! -e /etc/lighttpd/conf.d/userdir.conf ]
then
    /usr/bin/mkdir -p /etc/lighttpd/conf.d
    /usr/bin/cp /etc/defaults/etc/lighttpd/conf.d/userdir.conf /etc/lighttpd/conf.d/userdir.conf
fi

if [ ! -e /etc/lighttpd/conf.d/webdav.conf ]
then
    /usr/bin/mkdir -p /etc/lighttpd/conf.d
    /usr/bin/cp /etc/defaults/etc/lighttpd/conf.d/webdav.conf /etc/lighttpd/conf.d/webdav.conf
fi

if [ ! -e /etc/lighttpd/lighttpd.conf ]
then
    /usr/bin/mkdir -p /etc/lighttpd
    /usr/bin/cp /etc/defaults/etc/lighttpd/lighttpd.conf /etc/lighttpd/lighttpd.conf
fi

if [ ! -e /etc/lighttpd/modules.conf ]
then
    /usr/bin/mkdir -p /etc/lighttpd
    /usr/bin/cp /etc/defaults/etc/lighttpd/modules.conf /etc/lighttpd/modules.conf
fi

if [ ! -e /etc/lighttpd/vhosts.d/vhosts.template ]
then
    /usr/bin/mkdir -p /etc/lighttpd/vhosts.d
    /usr/bin/cp /etc/defaults/etc/lighttpd/vhosts.d/vhosts.template /etc/lighttpd/vhosts.d/vhosts.template
fi
